# sibi-dst

Data Science Toolkit
---------------------
Data Science Toolkit built with Python, Pandas, Dask, OpenStreetMaps, Scikit-Learn, XGBOOST, Django ORM, SQLAlchemy, DjangoRestFrameWork

Major Functionality
--------------------
1) Build DataCubes, DataSets and DataObjects from different datasources. These include relational databases, parquet files, xlsx, delimited tables, json, json API REST.
2) Common dataframe management utilities.
3) Share Data with client applications by write to Data Warehouses in local filesystems as well as other supported platforms.
4) Build microservices to communicate/share data via API-REST, gRPC.

